@@ -5,7 +5,7 @@ import shutil
 import subprocess as sp
 
 def __check_op() -> None:
-    if shutil.which('osp') is None:
+    if shutil.which('op') is None:
         raise RuntimeError('`op` is not installed')
 
 
